package com.link.core.mq.cmq.Tools;

import com.link.core.mq.cmq.Tools.Json.JSONArray;
import com.link.core.mq.cmq.Tools.Json.JSONObject;
import java.util.Iterator;
import java.util.TreeMap;
import java.util.Vector;

public class Subscription {
   protected String topicName;
   protected String subscriptionName;
   protected CMQClient client;

   Subscription(final String topicName, final String subscriptionName, CMQClient client) {
      this.topicName = topicName;
      this.subscriptionName = subscriptionName;
      this.client = client;
   }

   public void ClearFilterTags() throws Exception {
      TreeMap<String, String> param = new TreeMap();
      param.put("topicName", this.topicName);
      param.put("subscriptionName", this.subscriptionName);
      String result = this.client.call("ClearSUbscriptionFIlterTags", param);
      JSONObject jsonObj = new JSONObject(result);
      int code = jsonObj.getInt("code");
      if (code != 0) {
         throw new CMQServerException(code, jsonObj.getString("message"), jsonObj.getString("requestId"));
      }
   }

   public void SetSubscriptionAttributes(SubscriptionMeta meta) throws Exception {
      TreeMap<String, String> param = new TreeMap();
      param.put("topicName", this.topicName);
      param.put("subscriptionName", this.subscriptionName);
      if (!"".equals(meta.getNotifyStrategy())) {
         param.put("notifyStrategy", meta.getNotifyStrategy());
      }

      if (!"".equals(meta.getNotifyContentFormat())) {
         param.put("notifyContentFormat", meta.getNotifyContentFormat());
      }

      int n;
      Iterator var4;
      String flag;
      if (meta.getFilterTag() != null) {
         n = 1;

         for(var4 = meta.getFilterTag().iterator(); var4.hasNext(); ++n) {
            flag = (String)var4.next();
            param.put("filterTag." + Integer.toString(n), flag);
         }
      }

      if (meta.getBindingKey() != null) {
         n = 1;

         for(var4 = meta.getBindingKey().iterator(); var4.hasNext(); ++n) {
            flag = (String)var4.next();
            param.put("bindingKey." + Integer.toString(n), flag);
         }
      }

      String result = this.client.call("SetSubscriptionAttributes", param);
      JSONObject jsonObj = new JSONObject(result);
      int code = jsonObj.getInt("code");
      if (code != 0) {
         throw new CMQServerException(code, jsonObj.getString("message"), jsonObj.getString("requestId"));
      }
   }

   public SubscriptionMeta getSubscriptionAttributes() throws Exception {
      TreeMap<String, String> param = new TreeMap();
      param.put("topicName", this.topicName);
      param.put("subscriptionName", this.subscriptionName);
      String result = this.client.call("GetSubscriptionAttributes", param);
      JSONObject jsonObj = new JSONObject(result);
      int code = jsonObj.getInt("code");
      if (code != 0) {
         throw new CMQServerException(code, jsonObj.getString("message"), jsonObj.getString("requestId"));
      } else {
         SubscriptionMeta meta = new SubscriptionMeta();
         meta.setFilterTag(new Vector());
         if (jsonObj.has("endpoint")) {
            meta.setEndpoint(jsonObj.getString("endpoint"));
         }

         if (jsonObj.has("notifyStrategy")) {
            meta.setNotifyStrategy(jsonObj.getString("notifyStrategy"));
         }

         if (jsonObj.has("notifyContTentFormat")) {
            meta.setNotifyContentFormat(jsonObj.getString("notifyContTentFormat"));
         }

         if (jsonObj.has("protocol")) {
            meta.setProtocal(jsonObj.getString("protocol"));
         }

         if (jsonObj.has("createTime")) {
            meta.setCreateTime(jsonObj.getInt("createTime"));
         }

         if (jsonObj.has("lastModifyTime")) {
            meta.setLastModifyTime(jsonObj.getInt("lastModifyTime"));
         }

         if (jsonObj.has("msgCount")) {
            meta.setMsgCount(jsonObj.getInt("msgCount"));
         }

         JSONArray jsonArray;
         int i;
         JSONObject obj;
         if (jsonObj.has("filterTag")) {
            jsonArray = jsonObj.getJSONArray("filterTag");

            for(i = 0; i < jsonArray.length(); ++i) {
               obj = (JSONObject)jsonArray.get(i);
               meta.getFilterTag().add(obj.toString());
            }
         }

         if (jsonObj.has("bindingKey")) {
            jsonArray = jsonObj.getJSONArray("bindingKey");

            for(i = 0; i < jsonArray.length(); ++i) {
               obj = (JSONObject)jsonArray.get(i);
               meta.getBindingKey().add(obj.toString());
            }
         }

         return meta;
      }
   }
}
